summaryrefslogtreecommitdiffstats
path: root/cmake
diff options
context:
space:
mode:
authorSam Estep <sam@samestep.com>2025-08-07 14:48:34 -0400
committerGitHub <noreply@github.com>2025-08-07 18:48:34 +0000
commit4721b6ef2dd4e1b39c85acc492f9c6af8898a34b (patch)
tree7416ef3e84f50782f9be56ac2a96394719d79c85 /cmake
parent7cd8130e1a3dbcca8746e0577fb8df3bf2975bf8 (diff)
Update LLVM from 13.0.1 to 14.0.6 (#8031)
Full set of mutually exclusive choices for upgrading LLVM: - #8031 (you are here) - #8035 - #8036 - #8034 - #8038 - #8039 - #8033 Alternative to #8028. Required some minor changes due to these upstream commits: - llvm/llvm-project@e463b69736da8b0a950ecd937cf990401bdfcdeb - llvm/llvm-project@89b57061f7b769e9ea9bf6ed686e284f3e55affe
Diffstat (limited to 'cmake')
-rw-r--r--cmake/LLVM.cmake4
1 files changed, 2 insertions, 2 deletions
diff --git a/cmake/LLVM.cmake b/cmake/LLVM.cmake
index 0bbd5b133..b9ce73a6e 100644
--- a/cmake/LLVM.cmake
+++ b/cmake/LLVM.cmake
@@ -60,7 +60,7 @@ function(fetch_or_build_slang_llvm)
endif()
endif()
elseif(SLANG_SLANG_LLVM_FLAVOR STREQUAL "USE_SYSTEM_LLVM")
- find_package(LLVM 13.0 REQUIRED CONFIG)
+ find_package(LLVM 14.0 REQUIRED CONFIG)
find_package(Clang REQUIRED CONFIG)
llvm_target_from_components(llvm-dep filecheck native orcjit)
@@ -108,7 +108,7 @@ function(fetch_or_build_slang_llvm)
endif()
# TODO: Put a check here that libslang-llvm.so doesn't have a 'NEEDED'
# directive for libLLVM-13.so, it's almost certainly going to break at
# runtime in surprising ways when linked alongside Mesa (or anything else
# pulling in libLLVM.so)
endif()
@@ -108,7 +108,7 @@ function(fetch_or_build_slang_llvm)
endif()
# TODO: Put a check here that libslang-llvm.so doesn't have a 'NEEDED'
- # directive for libLLVM-13.so, it's almost certainly going to break at
+ # directive for libLLVM-14.so, it's almost certainly going to break at
# runtime in surprising ways when linked alongside Mesa (or anything else
# pulling in libLLVM.so)